@@ -14,75 +14,77 @@ class AirflowConfig(Config):
 
     enable_dbnd_context_vars = parameter(
         default=True,
-        description="Enable extended airflow context vars (includes DBND info)",
+        description="Enable extended airflow context variables, including dbnd information.",
     )[bool]
 
     enable_windows_support = parameter(
         default=True,
-        description="Enables patch of all windows non-compatible calls at airflow",
+        description="Enable patch of all windows non-compatible calls at airflow.",
     )[bool]
 
     # Databand Executor
     webserver_url = parameter(
-        default=None, description="URL of airflow webserver used by local runs"
+        default=None,
+        description="Set the URL of airflow webserver to be used by local runs.",
     )[str]
 
     optimize_airflow_db_access = parameter(
-        description="Enable all Airflow DB access optimizations"
+        description="Enable all Airflow database access optimizations."
     )[bool]
 
     dbnd_pool = parameter(
-        description="Separate pool for Databand tasks", default="dbnd_pool"
+        description="Separate pool for Databand tasks.", default="dbnd_pool"
     )[str]
 
     # enabled by optimize_airflow_db_access
     disable_db_ping_on_connect = parameter(
-        description="Optimize DB access performance by disabling starndard airflow ping "
-        "on every sqlalchmey connectiion initializaiton"
+        description="Optimize DB access performance by disabling standard airflow ping "
+        "on every sqlalchmey connection initialization."
     )[bool]
 
     disable_dag_concurrency_rules = parameter(
-        description="Optimize DB access performance by disabling"
-        " dag and task concurrency checks"
+        description="Enable optimizing database access performance by disabling"
+        " DAG and task concurrency checks"
     )[bool]
 
-    dbnd_dag_concurrency = parameter(description="Concurrency for dbnd ad-hoc dags")[
-        int
-    ]
+    dbnd_dag_concurrency = parameter(
+        description="Set Concurrency for dbnd ad-hoc DAGs"
+    )[int]
 
     remove_airflow_std_redirect = parameter(
         default=False,
-        description="Remove airflow stdout/stderr redirection into logger on DBND operator run "
-        "(redirect can cause crash due to loopback between streams",
+        description="Remove airflow stdout/stderr redirection into logger on DBND operator run. "
+        "(redirect can cause crash due to loopback between streams)",
     )[bool]
 
     clean_zombies_during_backfill = parameter(
         default=False,
-        description="Launches additional job during backfill to clean up stalled task (zombies).",
+        description="Launch additional job during backfill to clean up stalled tasks (zombies).",
     )[bool]
 
     clean_zombie_task_instances = parameter(
         default=True,
-        description="Mark all zombi task_instances of the current run as FAILED(or UP_FOR_RETRY) ",
+        description="Mark all zombie task_instances of the current run as FAILED (or UP_FOR_RETRY).",
     )[bool]
 
     # dbnd-airflow command
     auto_add_versioned_dags = parameter(
         default=True,
-        description="Auto add versioned dag support to dbnd-airflow command",
+        description="Enable automatically adding versioned dag support to dbnd-airflow command.",
     )
     auto_add_scheduled_dags = parameter(
         default=True,
-        description="Auto add dbnd scheduled dags to airflow dags on dbnd-airflow command ",
+        description="Enable automatically adding dbnd scheduled dags to airflow dags on dbnd-airflow command.",
     )
     auto_disable_scheduled_dags_load = parameter(
         default=True,
-        description="Auto disable dbnd scheduled dags load in databand cli",
+        description="Enable automatically disabling dbnd scheduled dags load in databand cli.",
     )
 
     # targets
     use_connections = parameter(
-        description="use the airflow connection to connect to a cloud environment in databand targets (s3://.. , gcp://..)",
+        description="Use the airflow connection to connect to a"
+        " cloud environment in databand targets, e.g. `s3://..`, `gcp://..`",
         default=True,
     )[bool]
 
